@@ -1,5 +1,29 @@
+// --------------------------------------------------------------------------
+// This file is part of the pmpd software.
+//
+//    pmpd software is free software: you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation, either version 3 of the License, or
+//    (at your option) any later version.
+//
+//    pmpd firmware is distributed in the hope that it will be useful,
+//    but WITHOUT ANY WARRANTY; without even the implied warranty of
+//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//    GNU General Public License for more details.
+//
+//    You should have received a copy of the GNU General Public License
+//    along with pmpd software. If not, see <http://www.gnu.org/licenses/>.
+// -------------------------------------------------------------------------- 
+//
+// pmpd = physical modeling for pure data
+// ch@chnry.net
+
+
 #include "m_pd.h"
-#include "math.h"
+#include <math.h>
+
+#include "pmpd_export.h"
+#include "pmpd_version.h"
 
 #define max(a,b) ( ((a) > (b)) ? (a) : (b) ) 
 #define min(a,b) ( ((a) < (b)) ? (a) : (b) ) 
@@ -26,11 +50,11 @@ static int makeseed2D(void)
     return (random_nextseed & 0x7fffffff);
 }
 
-static float random_bang2D(t_mass2D *x)
+static t_float random_bang2D(t_mass2D *x)
 {
     int nval;
     int range = 2000000;
-	float rnd;
+	t_float rnd;
 	unsigned int randval = x->x_state;
 	x->x_state = randval = randval * 472940017 + 832416023;
     nval = ((double)range) * ((double)randval)
@@ -339,7 +363,7 @@ void mass2D_inter_ambient(t_mass2D *x, t_symbol *s, int argc, t_atom *argv)
 	}
 	else
 	{
-		error("bad ambient interraction message");
+		logpost(x,1,"bad ambient interraction message");
 	}
 }
 
@@ -347,7 +371,7 @@ void mass2D_inter_seg(t_mass2D *x, t_symbol *s, int argc, t_atom *argv)
 {
 t_float a1, b1, c1, a2, b2, c2, a3, b3, c3, tmp;
 t_float posx1, posx2, posy1, posy2;
-t_float profondeur, prof_max;
+t_float profondeur;
 
 	if (argc == 12) 
 		// 0 : posx1
@@ -440,7 +464,7 @@ t_float profondeur, prof_max;
 	}
 	else
 	{
-		error("bad interact_2D_segment message");
+		logpost(x,1,"bad interact_2D_segment message");
 	}
 }
 
@@ -448,7 +472,7 @@ void mass2D_inter_line(t_mass2D *x, t_symbol *s, int argc, t_atom *argv)
 {
 t_float a1, b1, c1, tmp;
 t_float posx1, posx2, posy1, posy2;
-t_float profondeur, prof_max;
+t_float profondeur;
 
 	if (argc == 12) 
 		// 0 : posx1
@@ -517,16 +541,16 @@ t_float profondeur, prof_max;
 	}
 	else
 	{
-		error("bad interact_2D_line message");
+		logpost(x,1,"bad interact_2D_line message");
 	}
 }
 
 void mass2D_inter_circle(t_mass2D *x, t_symbol *s, int argc, t_atom *argv)
 {
-t_float posx1, posy1, Nx, Ny, dx, dy, distance, Dmax, tmp;
+t_float posx1, posy1, Nx, Ny, distance, Dmax, tmp;
 t_float deltaX_old, deltaY_old, distance_old ;
-t_float fnx=0, fny=0;
-t_float ftx=0, fty=0;
+t_float fnx=0;
+t_float ftx=0;
 
 	if (argc == 20) 
 		// 0 : Xcentre
@@ -680,7 +704,7 @@ t_float ftx=0, fty=0;
 	}
 	else
 	{
-		error("bad interact_2D_circle message");
+		logpost(x,1,"bad interact_2D_circle message");
 	}
 }
 
@@ -770,7 +794,7 @@ static void mass2D_free(t_mass2D *x)
     pd_unbind(&x->x_obj.ob_pd, x->x_sym);
 }
 
-void mass2D_setup(void) 
+PMPD_EXPORT void mass2D_setup(void)
 {
 
   mass2D_class = class_new(gensym("mass2D"),
@@ -778,6 +802,11 @@ void mass2D_setup(void)
         (t_method)mass2D_free, sizeof(t_mass2D),
         CLASS_DEFAULT, A_GIMME, 0);
 
+  if(!mass2D_class)
+      return;
+
+  verbose(4, "mass2D version %s (%s)", pmpd_tag(), pmpd_sha());
+
   class_addcreator((t_newmethod)mass2D_new, gensym("masse2D"), A_GIMME, 0);
 
   class_addbang(mass2D_class, mass2D_bang);
