@@ -1,5 +1,29 @@
+// --------------------------------------------------------------------------
+// This file is part of the pmpd software.
+//
+//    pmpd software is free software: you can redistribute it and/or modify
+//    it under the terms of the GNU General Public License as published by
+//    the Free Software Foundation, either version 3 of the License, or
+//    (at your option) any later version.
+//
+//    pmpd firmware is distributed in the hope that it will be useful,
+//    but WITHOUT ANY WARRANTY; without even the implied warranty of
+//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//    GNU General Public License for more details.
+//
+//    You should have received a copy of the GNU General Public License
+//    along with pmpd software. If not, see <http://www.gnu.org/licenses/>.
+// -------------------------------------------------------------------------- 
+//
+// pmpd = physical modeling for pure data
+// ch@chnry.net
+
+
 #include "m_pd.h"
-#include "math.h"
+#include <math.h>
+
+#include "pmpd_export.h"
+#include "pmpd_version.h"
 
 #define max(a,b) ( ((a) > (b)) ? (a) : (b) ) 
 #define min(a,b) ( ((a) < (b)) ? (a) : (b) ) 
@@ -26,11 +50,11 @@ static int makeseed3D(void)
     return (random_nextseed & 0x7fffffff);
 }
 
-static float random_bang3D(t_mass3D *x)
+static t_float random_bang3D(t_mass3D *x)
 {
     int nval;
     int range = 2000000;
-	float rnd;
+	t_float rnd;
 	unsigned int randval = x->x_state;
 	x->x_state = randval = randval * 472940017 + 832416023;
     nval = ((double)range) * ((double)randval)
@@ -94,7 +118,7 @@ void mass3D_damp(t_mass3D *x, t_floatarg f1)
   x->damp = f1;
 }
 
-void mass3D_loadbang(t_mass3D *x, t_float posZ)
+void mass3D_loadbang(t_mass3D *x)
 {
   outlet_anything(x->position3D_new, gensym("position3D"), 3, x->pos_new);
 }
@@ -462,13 +486,13 @@ void mass3D_inter_ambient(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 	}
 	else
 	{
-		error("bad ambient interraction message");
+		logpost(x,1,"bad ambient interraction message");
 	}
 }
 
 void mass3D_inter_plane(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 {
-	t_float a, b, c, d, profondeur, distance, tmp, profondeur_old;
+	t_float a, b, c, d, profondeur, tmp, profondeur_old;
 
 	if (argc == 12) 
 		// 0 : Xvector
@@ -557,15 +581,14 @@ void mass3D_inter_plane(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 	}	
 	else
 	{
-		error("bad plane interraction message");
+		logpost(x,1,"bad plane interraction message");
 	}
 }
 
 
 void mass3D_inter_sphere(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 {
-t_float posx1, posy1, posz1, Nx, Ny, Nz, dx, dy, dz, distance, Dmax, tmp;
-t_float deltaX_old, deltaY_old, deltaZ_old, distance_old ;
+t_float posx1, posy1, posz1, Nx, Ny, Nz, distance, Dmax, tmp;
 
 	if (argc == 17) 
 		// 0 : Xcentre
@@ -601,7 +624,7 @@ t_float deltaX_old, deltaY_old, deltaZ_old, distance_old ;
 		Nz = Nz/distance;							// composante Y de la normal.
 
 		Dmax= atom_getfloatarg(4, argc, argv);		// distance max de l'interaction
-		if ( (distance > atom_getfloatarg(3, argc, argv)) & (distance < Dmax) )
+		if ( (distance > atom_getfloatarg(3, argc, argv)) && (distance < Dmax) )
 		{
 			tmp = atom_getfloatarg(5, argc, argv); // force constante normal
 			x->forceX += tmp * Nx;
@@ -671,14 +694,14 @@ t_float deltaX_old, deltaY_old, deltaZ_old, distance_old ;
 	}
 	else
 	{
-		error("bad interact_3D_sphere message");
+		logpost(x,1,"bad interact_3D_sphere message");
 	}
 }
 
 
 void mass3D_inter_circle(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 {
-	t_float a, b, c, d, profondeur, distance, tmp, profondeur_old, rayon, rayon_old;
+	t_float a, b, c, d, profondeur, tmp, profondeur_old, rayon;
 
 	if (argc == 14) 
 		// 0 : Xvector
@@ -724,9 +747,9 @@ void mass3D_inter_circle(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 
 		profondeur = a * x->posX_old_1 + b * x->posY_old_1 + c * x->posZ_old_1 - d;
 
-		rayon = sqrt ( pow(x->posX_old_1-atom_getfloatarg(3, argc, argv), 2) +pow(x->posY_old_1-atom_getfloatarg(4, argc, argv) , 2)  + pow(x->posZ_old_1 - atom_getfloatarg(5, argc, argv) , 2) - profondeur*profondeur );
+		rayon = sqrt ( pow(x->posX_old_1-atom_getfloatarg(3, argc, argv), 2) + pow(x->posY_old_1-atom_getfloatarg(4, argc, argv) , 2) + pow(x->posZ_old_1 - atom_getfloatarg(5, argc, argv) , 2) - profondeur*profondeur );
 
-		if ( (profondeur < 0) & (profondeur > - atom_getfloatarg(11, argc, argv)) & (rayon > atom_getfloatarg(6, argc, argv)) & (rayon < atom_getfloatarg(7, argc, argv)))
+		if ( (profondeur < 0) && (profondeur > - atom_getfloatarg(11, argc, argv)) && (rayon > atom_getfloatarg(6, argc, argv)) && (rayon < atom_getfloatarg(7, argc, argv)))
 		{
 
 			tmp = atom_getfloatarg(8, argc, argv); // force normal constante
@@ -764,14 +787,14 @@ void mass3D_inter_circle(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 	}	
 	else
 	{
-		error("bad circle interraction message");
+		logpost(x,1,"bad circle interraction message");
 	}
 }
 
 
 void mass3D_inter_cylinder(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 {
-	t_float a, b, c, d, profondeur, profondeur_old, distance, tmp, rayon_old, rayon;
+	t_float a, b, c, d, profondeur, profondeur_old, tmp, rayon_old, rayon;
 	t_float Xb, Yb, Zb, Ta, Tb, Tc, Xb_old, Yb_old, Zb_old;
 
 	if (argc == 21) 
@@ -850,7 +873,7 @@ void mass3D_inter_cylinder(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 		Tb = c*Xb - a*Zb;
 		Tc = a*Yb - b*Xb;
 		
-		if ( (profondeur < atom_getfloatarg(14, argc, argv)) & (profondeur > atom_getfloatarg(13, argc, argv)) & (rayon < atom_getfloatarg(7, argc, argv)) & (rayon > atom_getfloatarg(6, argc, argv)) )
+		if ( (profondeur < atom_getfloatarg(14, argc, argv)) && (profondeur > atom_getfloatarg(13, argc, argv)) && (rayon < atom_getfloatarg(7, argc, argv)) && (rayon > atom_getfloatarg(6, argc, argv)) )
 		{
 
 			tmp = atom_getfloatarg(8, argc, argv); // force normal constante
@@ -936,7 +959,7 @@ void mass3D_inter_cylinder(t_mass3D *x, t_symbol *s, int argc, t_atom *argv)
 	}	
 	else
 	{
-		error("bad cylinder interraction message");
+		logpost(x,1,"bad cylinder interraction message");
 	}
 }
 
@@ -1049,7 +1072,7 @@ static void mass3D_free(t_mass3D *x)
 }
 
 
-void mass3D_setup(void) 
+PMPD_EXPORT void mass3D_setup(void)
 {
 
   mass3D_class = class_new(gensym("mass3D"),
@@ -1058,6 +1081,11 @@ void mass3D_setup(void)
 		sizeof(t_mass3D),
         CLASS_DEFAULT, A_GIMME, 0);
 
+  if(!mass3D_class)
+      return;
+
+  verbose(4, "mass3D version %s (%s)", pmpd_tag(), pmpd_sha());
+
   class_addcreator((t_newmethod)mass3D_new, gensym("masse3D"), A_GIMME, 0);
 
   class_addmethod(mass3D_class, (t_method)mass3D_force, gensym("force3D"),A_DEFFLOAT, A_DEFFLOAT, A_DEFFLOAT, 0);
